/* $Id: starter_pdfa1b.java,v 1.4.2.3 2016/12/15 12:03:09 stm Exp $
 *
 * PDF/A-1b starter:
 * Create PDF/A-1b conforming output
 *
 * Required software: PDFlib/PDFlib+PDI/PPS 9
 * Required data: font file, image file
 */

import com.pdflib.pdflib;
import com.pdflib.PDFlibException;

public class starter_pdfa1b {
    public static void main(String argv[]) {
        /* This is where the data files are. Adjust as necessary. */
        String searchpath = "../data";

        pdflib p = null;
        String imagefile = "nesrin.jpg";

        int font;
        int image;

        try {
            p = new pdflib();

            /*
             * This means we must check return values of load_font() etc.
             * Set the search path for fonts and images etc.
             */
            p.set_option("errorpolicy=return SearchPath={{" + searchpath + "}}");

            /* PDF/A-1a requires Tagged PDF */
            if (p.begin_document("starter_pdfa1b.pdf", "pdfa=PDF/A-1b:2005") == -1)
                throw new Exception("Error: " + p.get_errmsg());

            /*
             * We use sRGB as output intent since it allows the color spaces
             * CIELab, ICC-based, grayscale, and RGB.
             * 
             * If you need CMYK color you must use a CMYK output profile.
             */

            p.load_iccprofile("sRGB", "usage=outputintent");

            p.set_info("Creator", "PDFlib starter sample");
            p.set_info("Title", "starter_pdfa1b");

            p.begin_page_ext(595, 842, "");

            /* Font embedding is required for PDF/A */
            font = p.load_font("LuciduxSans-Oblique", "unicode", "embedding");

            if (font == -1)
                throw new Exception("Error: " + p.get_errmsg());

            p.setfont(font, 24);

            p.fit_textline("PDF/A-1b:2005 starter", 50, 700, "");

            /*
             * We can use an RGB image since we already supplied an output
             * intent profile.
             */
            image = p.load_image("auto", imagefile, "");

            if (image == -1)
                throw new Exception("Error: " + p.get_errmsg());

            /* Place the image at the bottom of the page */
            p.fit_image(image, 0.0, 0.0, "scale=0.5");

            p.end_page_ext("");
	    p.close_image(image);

            p.end_document("");

        }
        catch (PDFlibException e) {
            System.err.println("PDFlib exception occurred:");
            System.err.println("[" + e.get_errnum() + "] " + e.get_apiname()
                    + ": " + e.get_errmsg());
        }
        catch (Exception e) {
            System.err.println(e.getMessage());
        }
        finally {
            if (p != null) {
                p.delete();
            }
        }
    }
}
